==> py-football-1.0.0.tar.gz: py-football-1.0.0/README.md <==
# py-football library for Roanuz Football API
py-football library for Python using Roanuz Football API's.  Easy to install and simple way to access all Roanuz Football API's. Its a Python library for getting Live Football Score, Cricket Schedule and Statistics.


## Getting started
1. Install py-football using `pip install py-football`

2. Create a Football API App here [My APP Login](https://www.footballapi.com/login/?next=/apps/)

1. Import pyfootball and create Authentication using 'RcaFileStorageHandler' or 'RcaStorageHandler' approach.For accessing each API we need to get the 'AccessToken' 

    ## Example

    ```rust
    //Use your Football API Application details below.

    //RcaStorageHandler
    import pyfootball
    handler = pyfootball.RcaStorageHandler()
    start = pyfootball.RfaApp(access_key="Your_AccessKey", \
                            secret_key="Your_SecretKey", \
                            app_id="Your_APP_ID", \
                            store_handler=handler \
                           )

    'OR'

    //RcaFileStorageHandler(from environmental variable)

    Environmental variable:
        RFA_ACCESS_KEY = access_key
        RFA_SECRET_KEY = secret_key
        RFA_APP_ID = app_id

    handler = pyfootball.RfaFileStorageHandler()
    start = pyfootball.RfaApp(store_handler=handler)

    // After Completing Authentication you can successfully access the API's.

    start.get_match(<match_key>) //Return Match information in json format
    start.get_tournament(<tournament_key>) //Return tournament information in json format
    For more free API's visit : https://www.footballapi.com/docs/freeapi/
    ```


 ### List of Roanuz Football API's

* [Match API](https://www.footballapi.com/docs/Core-API/Match-API/)  start.get_match("match_key")
* [Tournament API](https://www.footballapi.com/docs/Core-API/Tournament-API/) start.get_tournament("tournament_key")
* [Tournament Team API](https://www.footballapi.com/docs/Core-API/Tournamant-Team-API/)  start.get_tournament_team("tournament_key", "team_key")
* [Tournament Round API](https://www.footballapi.com/docs/Core-API/Tournament-Round-API/)  start.get_tournament_round("tournament_key", "round_key")
* [Tournament Stats API](https://www.footballapi.com/docs/Core-API/Tournament-Stats-API/)  start.get_tournament_stats("tournament_key")
* [Tournament Team Stats API](https://www.footballapi.com/docs/Core-API/Tournament-Team-Stats-API/)  start.get_tournament_team_stats("tournament_key", "team_key")
* [Tournament Player Stats API](https://www.footballapi.com/docs/Core-API/Tournament-Player-Stats-API/)  start.get_tournament_player_stats("tournament_key", "player_key")
* [Schedule API](https://www.footballapi.com/docs/Core-API/Schedule-API/)  start.get_schedule()
* [Tournament Schedule API](https://www.footballapi.com/docs/Core-API/Tournament-Schedule-API/)  start.get_tournament_schedule("tournament_key")
* [Recent Tournaments API](https://www.footballapi.com/docs/Core-API/Recent-Tournaments-API/)  start.get_recent_tournaments()
* [Round Matches API](https://www.footballapi.com/docs/Core-API/Round-Matches-API/)  start.get_round_matches("tournament_key", "round_key")
* [Recent Tournament Matches API](https://www.footballapi.com/docs/Core-API/Recent-Tournament-Matches-API/)  start.get_recent_tournament_matches("tournament_key")
* [Tournament Standings API](https://www.footballapi.com/docs/Core-API/Tournament-Standings-API/)  start.get_tournament_standings("tournament_key")

 ## Roanuz Football API 
	This Library uses the Roanuz Football API for fetching football scores and stats.

 ## Contact:
    Feel free to call us anytime, We have an amazing team to support you.
    You can contact us at : support@cricketapi.com

==> py-football-1.0.1.tar.gz: py-football-1.0.1/README.md <==
# py-football library for Roanuz Football API
py-football library for Python using Roanuz Football API's.  Easy to install and simple way to access all Roanuz Football API's. Its a Python library for getting Live Football Score, Cricket Schedule and Statistics.


## Getting started
1. Install py-football using `pip install py-football`

2. Create a Football API App here [My APP Login](https://www.footballapi.com/login/?next=/apps/)

1. Import pyfootball and create Authentication using 'RcaFileStorageHandler' or 'RcaStorageHandler' approach.For accessing each API we need to get the 'AccessToken' 

    ## Example

    ```rust
    //Use your Football API Application details below.

    //RcaStorageHandler
    import pyfootball
    handler = pyfootball.RfaStorageHandler()
    start = pyfootball.RfaApp(access_key="Your_AccessKey", \
                            secret_key="Your_SecretKey", \
                            app_id="Your_APP_ID", \
                            store_handler=handler \
                           )

    'OR'

    //RcaFileStorageHandler(from environmental variable)

    Environmental variable:
        RFA_ACCESS_KEY = access_key
        RFA_SECRET_KEY = secret_key
        RFA_APP_ID = app_id

    handler = pyfootball.RfaFileStorageHandler()
    start = pyfootball.RfaApp(store_handler=handler)

    // After Completing Authentication you can successfully access the API's.

    start.get_match("match_key") //Return Match information in json format
    start.get_tournament("tournament_key") //Return tournament information in json format
    For more free API's visit : https://www.footballapi.com/docs/freeapi/
    ```


 ### List of Roanuz Football API's

* [Match API](https://www.footballapi.com/docs/Core-API/Match-API/)  start.get_match("match_key")
* [Tournament API](https://www.footballapi.com/docs/Core-API/Tournament-API/) start.get_tournament("tournament_key")
* [Tournament Team API](https://www.footballapi.com/docs/Core-API/Tournamant-Team-API/)  start.get_tournament_team("tournament_key", "team_key")
* [Tournament Round API](https://www.footballapi.com/docs/Core-API/Tournament-Round-API/)  start.get_tournament_round("tournament_key", "round_key")
* [Tournament Stats API](https://www.footballapi.com/docs/Core-API/Tournament-Stats-API/)  start.get_tournament_stats("tournament_key")
* [Tournament Team Stats API](https://www.footballapi.com/docs/Core-API/Tournament-Team-Stats-API/)  start.get_tournament_team_stats("tournament_key", "team_key")
* [Tournament Player Stats API](https://www.footballapi.com/docs/Core-API/Tournament-Player-Stats-API/)  start.get_tournament_player_stats("tournament_key", "player_key")
* [Schedule API](https://www.footballapi.com/docs/Core-API/Schedule-API/)  start.get_schedule()
* [Tournament Schedule API](https://www.footballapi.com/docs/Core-API/Tournament-Schedule-API/)  start.get_tournament_schedule("tournament_key")
* [Recent Tournaments API](https://www.footballapi.com/docs/Core-API/Recent-Tournaments-API/)  start.get_recent_tournaments()
* [Round Matches API](https://www.footballapi.com/docs/Core-API/Round-Matches-API/)  start.get_round_matches("tournament_key", "round_key")
* [Recent Tournament Matches API](https://www.footballapi.com/docs/Core-API/Recent-Tournament-Matches-API/)  start.get_recent_tournament_matches("tournament_key")
* [Tournament Standings API](https://www.footballapi.com/docs/Core-API/Tournament-Standings-API/)  start.get_tournament_standings("tournament_key")

 ## Roanuz Football API 
	This Library uses the Roanuz Football API for fetching football scores and stats.

 ## Contact:
    Feel free to call us anytime, We have an amazing team to support you.
    You can contact us at : support@cricketapi.com
